@@ -78,62 +78,24 @@ as_gt <- function(x, ...) {
 #' ) |>
 #'   summary() |>
 #'   as_gt()
-as_gt.fixed_design <- function(x, title = NULL, footnote = NULL, ...) {
-  method <- fd_method(x)
+as_gt.fixed_design_summary <- function(x, title = NULL, footnote = NULL, ...) {
+  if (is.null(title)) title <- attr(x, "title")
+  if (is.null(footnote)) footnote <- attr(x, "footnote")
+
   ans <- gt::gt(x) |>
-    gt::tab_header(title = title %||% fd_title(method))
-  if (!isFALSE(footnote)) ans <- ans |>
-    gt::tab_footnote(
-      footnote = footnote %||% fd_footnote(x, method),
-      locations = gt::cells_title(group = "title")
-    )
+    gt::tab_header(title = title)
+
+  if (!isFALSE(footnote)) {
+    ans <- ans |>
+      gt::tab_footnote(
+        footnote = footnote,
+        locations = gt::cells_title(group = "title")
+      )
+  }
+
   return(ans)
 }
 
-get_method <- function(x, methods) intersect(methods, class(x))[1]
-
-# get the fixed design method
-fd_method <- function(x) {
-  get_method(x, c("ahr", "fh", "mb", "lf", "rd", "maxcombo", "milestone", "rmst"))
-}
-
-# get the default title
-fd_title <- function(method) {
-  sprintf("Fixed Design %s Method", switch(
-    method,
-    ahr = "under AHR", fh = "under Fleming-Harrington", mb = "under Magirr-Burman",
-    lf = "under Lachin and Foulkes", maxcombo = "under MaxCombo",
-    milestone = "under Milestone", rmst = "under Restricted Mean Survival Time",
-    rd = "of Risk Difference under Farrington-Manning"
-  ))
-}
-
-# get the default footnote
-fd_footnote <- function(x, method) {
-  switch(
-    method,
-    ahr = "Power computed with average hazard ratio method.",
-    fh = paste(
-      "Power for Fleming-Harrington test", substring(x$Design, 19),
-      "using method of Yung and Liu."
-    ),
-    lf = paste(
-      "Power using Lachin and Foulkes method applied using expected",
-      "average hazard ratio (AHR) at time of planned analysis."
-    ),
-    rd = paste(
-      "Risk difference power without continuity correction using method of",
-      "Farrington and Manning."
-    ),
-    maxcombo = paste0(
-      "Power for MaxCombo test with Fleming-Harrington tests ",
-      substring(x$Design, 9), "."
-    ),
-    # for mb, milestone, and rmst
-    paste("Power for", x$Design, "computed with method of Yung and Liu.")
-  )
-}
-
 #' @rdname as_gt
 #'
 #' @param title A string to specify the title of the gt table.
@@ -243,7 +205,7 @@ fd_footnote <- function(x, method) {
 #'   summary() |>
 #'   as_gt(display_columns = c("Analysis", "Bound", "Nominal p", "Z", "Probability"))
 #' }
-as_gt.gs_design <- function(
+as_gt.gs_design_summary <- function(
     x,
     title = NULL,
     subtitle = NULL,
@@ -355,7 +317,7 @@ gsd_footnote <- function(method, columns) {
 # footnote for non-binding designs
 gsd_footnote_nb <- function(x, x_alpha) {
   full_alpha <- attr(x, "full_alpha")
-  if (!inherits(x, "non_binding") || x_alpha >= full_alpha) return()
+  if (attr(x, "binding") || x_alpha >= full_alpha) return()
   a1 <- format(x_alpha, scientific = FALSE)
   a2 <- format(full_alpha, scientific = FALSE)
   a3 <- format(full_alpha - x_alpha, scientific = FALSE)
@@ -387,7 +349,7 @@ gsd_parts <- function(
   x, title, subtitle, spannersub, footnote, bound, columns, inf_bound,
   transform = identity
 ) {
-  method <- intersect(c("ahr", "wlr", "combo", "rd"), class(x))[1]
+  method <- attr(x, "design")
   if (!inf_bound) x <- filter(x, !is.infinite(Z))
   # `x` needs a custom transformation in as_rtf()
   x2 <- transform(x)
