@@ -90,7 +90,7 @@ as_rtf <- function(x, ...) {
 #' ) |>
 #'   summary() |>
 #'   as_rtf(file = tempfile(fileext = ".rtf"))
-as_rtf.fixed_design <- function(
+as_rtf.fixed_design_summary <- function(
     x,
     title = NULL,
     footnote = NULL,
@@ -100,9 +100,10 @@ as_rtf.fixed_design <- function(
     file,
     ...) {
   orientation <- match.arg(orientation)
-  method <- fd_method(x)
-  title <- title %||% paste(fd_title(method), "{^a}")
-  footnote <- footnote %||% paste("{^a}", fd_footnote(x, method))
+  if (is.null(title)) title <- attr(x, "title")
+  if (is.null(footnote)) footnote <- attr(x, "footnote")
+  title <- paste(title, "{^a}")
+  footnote <- paste("{^a}", footnote)
 
   # set default column width
   n_row <- nrow(x)
@@ -266,7 +267,7 @@ check_rel_width <- function(width, n_col) {
 #'     file = tempfile(fileext = ".rtf")
 #'   )
 #' }
-as_rtf.gs_design <- function(
+as_rtf.gs_design_summary <- function(
     x,
     title = NULL,
     subtitle = NULL,
