@@ -23,13 +23,9 @@
 #' The piecewise exponential distribution allows a simple method to specify a distribution
 #' and enrollment pattern where the enrollment, failure and dropout rates changes over time.
 #'
-#' @param enroll_rate An `enroll_rate` data frame with or without stratum
-#'   created by [define_enroll_rate()].
-#' @param fail_rate A `fail_rate` data frame with or without stratum
-#'   created by [define_fail_rate()].
+#' @inheritParams ahr
 #' @param total_duration Total follow-up from start of enrollment to data
 #'   cutoff; this can be a single value or a vector of positive numbers.
-#' @param ratio Ratio of experimental to control randomization.
 #'
 #' @return A data frame with `time` (from `total_duration`), `stratum`, `t`,
 #'   `hr` (hazard ratio), `event` (expected number of events), `info`
@@ -175,16 +171,17 @@ pw_info <- function(
 
   # pool strata together for each time period
   tbl_event <- tbl_event[, .(
-    t = min(t),
     event = sum(event),
     info0 = sum(info0),
     info = sum(info)
-  ), by = .(time, stratum, hr)]
+  ), by = .(time, stratum, t, hr)]
 
   # -------------------------------------- #
   #    output the results                  #
   # -------------------------------------- #
-  ans <- merge(tbl_event, tbl_n, by = c("time", "t", "stratum"))
+  # merge 2 tables tbl_n and tbl_event, where they share the same time, t, stratum
+  ans <- tbl_event[tbl_n, on = c("time", "stratum", "t")]
+
   # filter out the rows with 0 events and unneeded columns
   ans <- ans[!almost_equal(event, 0L), .(time, stratum, t, hr, n, event, info, info0)]
 
