@@ -32,7 +32,7 @@ test_that("One-sided design fails to reproduce gsDesign package bounds", {
     upar = list(sf = sfu, total_spend = alpha, param = sfupar),
     lower = gs_b,
     lpar = rep(-Inf, K)
-  ) %>% dplyr::filter(bound == "upper")
+  ) |> dplyr::filter(bound == "upper")
 
   # Compare boundaries
   expect_equal(gsd$upper$bound, gsdv$z, tolerance = 7e-6)
@@ -40,7 +40,7 @@ test_that("One-sided design fails to reproduce gsDesign package bounds", {
 
   # Compare statistical information
   # While tolerance should not be problematic, it seems large
-  expect_equal(gsd$n.I, (gsdv %>% dplyr::filter(bound == "upper"))$info, tolerance = .04)
+  expect_equal(gsd$n.I, (gsdv |> dplyr::filter(bound == "upper"))$info, tolerance = .04)
 
   # Compare crossing boundaries probability
   expect_equal(gsdv$probability0, sfu(alpha = alpha, t = timing, param = sfupar)$spend)
@@ -73,16 +73,16 @@ test_that("Two-sided symmetric design fails to reproduce gsDesign test.type=2 bo
     tol = 1e-6
   )
   # Compare boundaries
-  expect_equal(gsd$upper$bound, (gsdv %>% dplyr::filter(bound == "upper"))$z, tolerance = 7e-6)
-  expect_equal(gsd$lower$bound, (gsdv %>% dplyr::filter(bound == "lower"))$z, tolerance = 7e-6)
+  expect_equal(gsd$upper$bound, (gsdv |> dplyr::filter(bound == "upper"))$z, tolerance = 7e-6)
+  expect_equal(gsd$lower$bound, (gsdv |> dplyr::filter(bound == "lower"))$z, tolerance = 7e-6)
 
   # Compare statistical information
   # While tolerance should not be problematic, it seems large
-  expect_equal(gsd$n.I, (gsdv %>% dplyr::filter(bound == "upper"))$info, tolerance = .04)
+  expect_equal(gsd$n.I, (gsdv |> dplyr::filter(bound == "upper"))$info, tolerance = .04)
 
   # Compare crossing boundaries probability
   expect_equal(
-    (gsdv %>% dplyr::filter(bound == "upper"))$probability0,
+    (gsdv |> dplyr::filter(bound == "upper"))$probability0,
     sfu(alpha = alpha, t = timing, param = sfupar)$spend
   )
 })
@@ -113,20 +113,20 @@ test_that("Two-sided asymmetric design fails to reproduce gsDesign test.type=3 b
     lpar = list(sf = sfl, total_spend = beta, param = sflpar)
   )
   # Compare boundaries
-  expect_equal(gsd$upper$bound, (gsdv %>% dplyr::filter(bound == "upper"))$z, tolerance = 7e-6)
-  expect_equal(gsd$lower$bound, (gsdv %>% dplyr::filter(bound == "lower"))$z, tolerance = 9e-6)
+  expect_equal(gsd$upper$bound, (gsdv |> dplyr::filter(bound == "upper"))$z, tolerance = 7e-6)
+  expect_equal(gsd$lower$bound, (gsdv |> dplyr::filter(bound == "lower"))$z, tolerance = 9e-6)
 
   # Compare statistical information
   # While tolerance should not be problematic, it seems large
-  expect_equal(gsd$n.I, (gsdv %>% dplyr::filter(bound == "upper"))$info, tolerance = .04)
+  expect_equal(gsd$n.I, (gsdv |> dplyr::filter(bound == "upper"))$info, tolerance = .04)
 
   # Compare crossing boundaries probability under null hypothesis (theta = 0)
   expect_equal(
-    (gsdv %>% dplyr::filter(bound == "upper"))$probability0,
+    (gsdv |> dplyr::filter(bound == "upper"))$probability0,
     sfu(alpha = alpha, t = timing, param = sfupar)$spend
   )
   expect_equal(
-    (gsdv %>% dplyr::filter(bound == "lower"))$probability,
+    (gsdv |> dplyr::filter(bound == "lower"))$probability,
     sfl(alpha = beta, t = timing, param = sflpar)$spend
   )
 })
@@ -158,30 +158,30 @@ test_that("Two-sided asymmetric design fails to reproduce gsDesign test.type=4 b
   )
 
   # Compare boundaries
-  expect_equal(gsd$upper$bound, (gsdv %>% dplyr::filter(bound == "upper"))$z, tolerance = 7e-6)
-  expect_equal(gsd$lower$bound, (gsdv %>% dplyr::filter(bound == "lower"))$z, tolerance = 9e-6)
+  expect_equal(gsd$upper$bound, (gsdv |> dplyr::filter(bound == "upper"))$z, tolerance = 7e-6)
+  expect_equal(gsd$lower$bound, (gsdv |> dplyr::filter(bound == "lower"))$z, tolerance = 9e-6)
 
   # Compare statistical information
   # While tolerance should not be problematic, it seems large
-  expect_equal(gsd$n.I, (gsdv %>% dplyr::filter(bound == "upper"))$info, tolerance = .04)
+  expect_equal(gsd$n.I, (gsdv |> dplyr::filter(bound == "upper"))$info, tolerance = .04)
 
   # Compare crossing boundaries probability under null hypothesis (theta = 0)
   expect_equal(
     gsdv$probability0,
-    gsDesign::gsBoundSummary(gsd) %>%
-      subset(Value == "P(Cross) if delta=0") %>%
-      dplyr::select(Efficacy, Futility) %>%
-      t() %>%
+    gsDesign::gsBoundSummary(gsd) |>
+      subset(Value == "P(Cross) if delta=0") |>
+      dplyr::select(Efficacy, Futility) |>
+      t() |>
       as.numeric(),
     tolerance = .0001
   )
 
   expect_equal(
     gsdv$probability,
-    gsDesign::gsBoundSummary(gsd) %>%
-      subset(Value == "P(Cross) if delta=1") %>%
-      dplyr::select(Efficacy, Futility) %>%
-      t() %>%
+    gsDesign::gsBoundSummary(gsd) |>
+      subset(Value == "P(Cross) if delta=1") |>
+      dplyr::select(Efficacy, Futility) |>
+      t() |>
       as.numeric(),
     tolerance = .0001
   )
@@ -215,28 +215,28 @@ test_that("Two-sided asymmetric design fails to reproduce gsDesign test.type=5 b
   )
 
   # Compare boundaries
-  expect_equal(gsd$upper$bound, (gsdv %>% dplyr::filter(bound == "upper"))$z, tolerance = 7e-6)
-  expect_equal(gsd$lower$bound, (gsdv %>% dplyr::filter(bound == "lower"))$z, tolerance = 9e-6)
+  expect_equal(gsd$upper$bound, (gsdv |> dplyr::filter(bound == "upper"))$z, tolerance = 7e-6)
+  expect_equal(gsd$lower$bound, (gsdv |> dplyr::filter(bound == "lower"))$z, tolerance = 9e-6)
 
   # Compare statistical information
   # While tolerance should not be problematic, it seems large
-  expect_equal(gsd$n.I, (gsdv %>% dplyr::filter(bound == "upper"))$info, tolerance = .04)
+  expect_equal(gsd$n.I, (gsdv |> dplyr::filter(bound == "upper"))$info, tolerance = .04)
 
   # Compare crossing boundaries probability under null hypothesis (theta = 0)
   expect_equal(
-    (gsdv %>% dplyr::filter(bound == "upper"))$probability0,
+    (gsdv |> dplyr::filter(bound == "upper"))$probability0,
     sfu(alpha = alpha, t = timing, param = sfupar)$spend
   )
   expect_equal(
     (gs_power_npe(
-      theta = 0, info = (gsdv %>% dplyr::filter(bound == "upper"))$info,
+      theta = 0, info = (gsdv |> dplyr::filter(bound == "upper"))$info,
       theta1 = 0, # Spending for lower bound under H0
       binding = TRUE, # Use this for test.type=3 and 5
       upper = gs_spending_bound,
       upar = list(sf = sfu, total_spend = alpha, param = sfupar),
       lower = gs_spending_bound,
       lpar = list(sf = sfl, total_spend = astar, param = sflpar)
-    ) %>%
+    ) |>
       dplyr::filter(bound == "lower")
     )$probability,
     sfl(alpha = astar, t = timing, param = sflpar)$spend
@@ -271,29 +271,29 @@ test_that("Two-sided asymmetric design fails to reproduce gsDesign test.type=6 b
   )
 
   # Compare boundaries
-  expect_equal(gsd$upper$bound, (gsdv %>% dplyr::filter(bound == "upper"))$z, tolerance = 7e-6)
-  expect_equal(gsd$lower$bound, (gsdv %>% dplyr::filter(bound == "lower"))$z, tolerance = 9e-6)
+  expect_equal(gsd$upper$bound, (gsdv |> dplyr::filter(bound == "upper"))$z, tolerance = 7e-6)
+  expect_equal(gsd$lower$bound, (gsdv |> dplyr::filter(bound == "lower"))$z, tolerance = 9e-6)
 
   # Compare statistical information
   # While tolerance should not be problematic, it seems large
-  expect_equal(gsd$n.I, (gsdv %>% dplyr::filter(bound == "upper"))$info, tolerance = .04)
+  expect_equal(gsd$n.I, (gsdv |> dplyr::filter(bound == "upper"))$info, tolerance = .04)
 
   # Compare crossing boundaries probability under null hypothesis (theta = 0)
   expect_equal(
-    (gsdv %>% dplyr::filter(bound == "upper"))$probability0,
+    (gsdv |> dplyr::filter(bound == "upper"))$probability0,
     sfu(alpha = alpha, t = timing, param = sfupar)$spend,
     tolerance = 1e-5
   )
   expect_equal(
     (gs_power_npe(
-      theta = 0, info = (gsdv %>% dplyr::filter(bound == "upper"))$info,
+      theta = 0, info = (gsdv |> dplyr::filter(bound == "upper"))$info,
       theta1 = 0, # Spending for lower bound under H0
       binding = TRUE, # Use this for test.type=3 and 5
       upper = gs_spending_bound,
       upar = list(sf = sfu, total_spend = alpha, param = sfupar),
       lower = gs_spending_bound,
       lpar = list(sf = sfl, total_spend = astar, param = sflpar)
-    ) %>%
+    ) |>
       dplyr::filter(bound == "lower")
     )$probability,
     sfl(alpha = astar, t = timing, param = sflpar)$spend
